@@ -1,4 +1,4 @@
 pub trait Str {
     // remove leading & ending spaces
-    fn trim_spaces(&self, str: &String) -> String;
+    fn trim_spaces(&self, string: &str) -> String;
 }
